ActivityLog class

Implementers

Constructors

ActivityLog({required int activityStatus, required String? userId, required String documentId})
ActivityLog.fromSnapshot(DocumentSnapshot<Map<String, dynamic>> snapshot)

Properties

activityStatus ↔ int
latefinal
documentId ↔ String
latefinal
hashCode → int
The hash code for this object.
no setter
path ↔ String
latefinal
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
reference → DocumentReference<Object?>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenBy ↔ List<String>
latefinal
seenStatus ↔ int
latefinal
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp ↔ DateTime
latefinal
userId ↔ String?
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object o) → bool
The equality operator.