TextActivity class

Inheritance

Constructors

TextActivity({required String documentId, required String text, String? userId})
TextActivity.fromSnapshot(DocumentSnapshot<Map<String, dynamic>> snap)

Properties

activityStatus ↔ int
latefinalinherited
documentId ↔ String
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String
latefinalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
reference → DocumentReference<Object?>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenBy ↔ List<String>
latefinalinherited
seenStatus ↔ int
latefinalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text ↔ String
latefinal
timestamp ↔ DateTime
latefinalinherited
userId ↔ String?
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object o) → bool
The equality operator.
inherited