ChatEntity class

Constructors

ChatEntity({required PeerUser mainUser, required Map<String, PeerUser> peers, required String path, required String? title, ActivityLog? lastMessage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastMessage → ActivityLog?
final
mainUser → PeerUser
final
path → String
final
peers → Map<String, PeerUser>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited