ChatModel class

Constructors

ChatModel.fromSnapshot(DocumentSnapshot<Map<String, Object?>> snapshot)

Properties

documentId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
lastMessageReference ↔ DocumentReference<Map<String, Object?>>?
latefinal
path ↔ String?
latefinal
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
reference → DocumentReference<Object?>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title ↔ String?
latefinal
users ↔ List<String>
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited