PeerUser class

Constructors

PeerUser({required String documentId, required String name, String? image})
PeerUser.fromSnapshot(DocumentSnapshot<Map<String, dynamic>> snapshot)

Properties

documentId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
latefinal
name ↔ String
latefinal
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
reference → DocumentReference<Object?>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited