BaseChatState<T extends BaseChat> class abstract

Inheritance

Constructors

BaseChatState()

Properties

activityRepository ↔ ActivityRepository
latefinal
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
emptyWidget → Widget
no setter
entity ↔ ChatEntity
latefinal
hashCode → int
The hash code for this object.
no setterinherited
images → List<GalleryViewItem>
final
listScrollController → ScrollController
final
loadingWidget → Widget
no setter
messageLimit → int
final
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
primaryColor → Color
no setter
query ↔ Query<Map<String, Object?>>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor → Color
no setter
textEditingController → TextEditingController
final
widget → BaseChat
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildItem(int i, List<ActivityLog> messages) → Widget
dataToModel(DocumentSnapshot<Map<String, dynamic>> snap) → FutureOr<ActivityLog>
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant BaseChat oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
editAndUpload(Uint8List data) → Future
errorWidget(String error) → Widget
getImage() → Future
initState() → void
Called when this object is inserted into the tree.
override
inputBuilder(BuildContext context, ChatInputState state) → Widget
inputChanged(String value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
sendImage(dynamic image) → Future<bool>
sendMessage() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited