ChatActivityWidget class

Inheritance

Constructors

ChatActivityWidget({Key? key, required ActivityLog activityLog, required int i, required String userId, required ActivityRepository activityRepository, required Widget loadingWidget, Color primaryColor = Colors.blue, List<ActivityLog>? listMessage, PeerUser? peer, required List<GalleryViewItem> images})
const

Properties

activityLog → ActivityLog
final
activityRepository → ActivityRepository
final
corner → Radius
final
flat → Radius
final
hashCode → int
The hash code for this object.
no setterinherited
i → int
final
images → List<GalleryViewItem>
final
isMe → bool
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listMessage → List<ActivityLog>?
final
loadingWidget → Widget
final
peer → PeerUser?
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
isLastMessageLeft(int index) → bool
isLastMessageRight(int index) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited